@@ -1,10 +1,7 @@
 from dbt.adapters.greenplum.connections import GreenplumConnectionManager
 from dbt.adapters.greenplum.connections import GreenplumCredentials
-from dbt.adapters.greenplum.relation import GreenplumColumn
-from dbt.adapters.greenplum.relation import GreenplumRelation
 from dbt.adapters.greenplum.impl import GreenplumAdapter
 
-
 from dbt.adapters.base import AdapterPlugin
 from dbt.include import greenplum
 
