@@ -5,8 +5,8 @@
   {%- set distributed_by = config.get('distributed_by', none) -%}
   {%- set appendonly = config.get('appendonly', default='true') -%}
   {%- set orientation = config.get('orientation', default='column') -%}
-  {%- set compresstype = config.get('compresstype', default='ZSTD') -%}
-  {%- set compresslevel = config.get('compresslevel', default=4) -%}
+  {%- set compresstype = config.get('compresstype', default='ZLIB') -%}
+  {%- set compresslevel = config.get('compresslevel', default=1) -%}
   {%- set blocksize = config.get('blocksize', default=32768) -%}
 
   {%- set raw_partition = config.get('raw_partition', none) -%}
@@ -27,7 +27,7 @@
 
   {{ sql_header if sql_header is not none }}
 
-  {% if is_partition %}
+  {% if is_partition and not temporary %}
 
     {# CREATING TABLE #}
     create table if not exists {{ relation }} (
@@ -122,6 +122,21 @@
   ({{ comma_separated_columns }});
 {%- endmacro %}
 
+{% macro greenplum__generate_schema_name(custom_schema_name, node) -%}
+
+    {%- set default_schema = target.schema -%}
+    {%- if custom_schema_name is none -%}
+
+    {{ default_schema }}
+
+    {%- else -%}
+
+    {{ custom_schema_name | trim }}
+
+    {%- endif -%}
+
+{%- endmacro %}
+
 {% macro greenplum__create_schema(relation) -%}
   {% if relation.database -%}
     {{ adapter.verify_database(relation.database) }}
